#!/bin/ksh
#DEBUG=TRUE
if [[ ${DEBUG} = TRUE ]]; then
    set -x
fi

#####################################################################
#
# Header
#
# Licensed Materials - Property of IBM Corp.
# (C) Copyright IBM Corp. 2004
# 
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.

    SCRIPT_VER=01.02
    SCRIPT_DATE=11/26/2004
    SCRIPT_SCCS=

#####################################################################
#
# History
#
# DATE        Ver    Auth         Abstract
# ----------  -----  -----------  ----------------------------------
# 11/15/2004  00.01  brookh       initial design 
# 11/18/2004  01.00  brookh       add "-v" option
# 11/26/2004  01.01  brookh       Check server status before stop/start
# 11/26/2004  01.02  brookh       .pid file is not reliable immediately after 
#                                  start/stop, so only check before first start

#####################################################################
#
# Usage: ${WAS_HOME}/bin/deploy_IDSWebApp.sh [-v] [IDSWebApp.war file]
# 
# Deploys IDSWebApp.war to WAS, retaining the configuration settings of
# the currently deployed IDSWebApp, if any. 
# 
# 1)  deploy_IDSWebApp.sh must be copied to ${WAS_HOME}/bin
# 
# 2)  There are 2 optional cmd line parameters which may appear in any 
#     order: 
#     
#     -v
#        
#         "version". If "-v" appears anywhere in the command line, 
#         then the version and date strings for the deploy_IDSWebApp 
#         script, the currently deployed IDSWebApp.war, and the new 
#         IDSWebApp.war will be displayed, but the new IDSWebApp.war 
#         will not be deployed. Otherwise, the IDSWebApp.war 
#         parameter functions as described below.
#     
#     IDSWebApp.war file
#     
#         The IDSWebApp.war file to deploy. Defaults to 
#         "${WAS_HOME}/installableApps/IDSWebApp.war" if not specified. 

#####################################################################
#
# Set QualifiedPath of $1, or return error and clear QualifiedPath
#
QualifiedPath=
QualifyPath()
{
    if [[ ${DEBUG} = TRUE ]]; then
        set -x
    fi

    if [[ -n $1 ]]; then
        QualifiedPath=
        save_PWD=$(pwd)
        cd $(dirname ${1}) || return $?
        QualifiedPath=$(pwd)/$(basename ${1})
        cd ${save_PWD}
    else 
        QualifiedPath=$(pwd)
    fi
}

#####################################################################
#
# Print localized "File not found" error and return failure RC
#
AssertFileExists()
{
    if [[ ${DEBUG} = TRUE ]]; then
        set -x
    fi
    
    if [[ ! -f $1 ]]; then
        ls $1 >/dev/null
    fi
}

#####################################################################
#
# Echo cmd and then call it
#
EchoCmd()
{
    if [[ ${DEBUG} = TRUE ]]; then
        set -x
    fi
    
    print "\n$*"
    eval $*
}

#####################################################################
#
PATCH_SCRIPT=
WAS_SERVER=server1
WAS_TEMP=
APP_ROOT=
IDSWebApp=
OPTION_V=FALSE
IDSWebAppInfo=WEB-INF/classes/IDSConfig/IDSWebAppInfo/IDSWebAppInfo.xml
CONFIG_FILES="\
    WEB-INF/classes/security/console_passwd \
    WEB-INF/classes/IDSConfig/IDSServersConfig/IDSServersInfo.xml \
    WEB-INF/classes/IDSConfig/IDSAppReg/IDSAppReg.xml \
    WEB-INF/classes/IDSConfig/IDSSessionConfig/IDSSessionMgmt.xml \
    "
    
InitGlobalVariables()
{
    if [[ ${DEBUG} = TRUE ]]; then
        set -x
    fi
    
    QualifyPath $0 || return $?
    PATCH_SCRIPT=${QualifiedPath}
    PATCH_DIR=$(dirname ${PATCH_SCRIPT})
    
    AssertFileExists "${PATCH_DIR}/setupCmdLine.sh" || return $?
    . "${PATCH_DIR}/setupCmdLine.sh" || return $?

    WAS_TEMP="${WAS_HOME}/temp/deploy_IDSWebApp.tmp"
    APP_ROOT="${WAS_HOME}/installedApps/${WAS_NODE}/IDSWebApp.war.ear/IDSWebApp.war"

    while [[ -n $1 ]]; do
        if [[ ${1} = -v ]]; then
            OPTION_V=TRUE
        else
            QualifyPath $1 || return $?
            IDSWebApp=${QualifiedPath}
        fi
        shift
    done
    
    if [[ -z ${IDSWebApp} ]]; then
        IDSWebApp="${WAS_HOME}/installableApps/IDSWebApp.war"
    fi
}

#####################################################################
#

# Delete ${WAS_HOME}/temp/IDSWebApp.tmp directory
#
DeleteTempDirectory()
{
    if [[ ${DEBUG} = TRUE ]]; then
        set -x
    fi
    
    if [[ -d ${WAS_TEMP} ]]; then
        rm -rf ${WAS_TEMP}
    fi
}

#####################################################################
#
# Create empty ${WAS_HOME}/temp/IDSWebApp.tmp directory
#
CreateTempDirectory()
{
    if [[ ${DEBUG} = TRUE ]]; then
        set -x
    fi
    
    DeleteTempDirectory || return $?
    mkdir -p ${WAS_TEMP} || return $?
}

#####################################################################
#
# Backup CONFIG_FILES (if any) from APP_ROOT to WAS_TEMP
#
Backup_IDSWebApp_Configuration()
{
    if [[ ${DEBUG} = TRUE ]]; then
        set -x
    fi
    
    #Set up the environment variables

    if [[ ! -d ${APP_ROOT} ]]; then
        return 0
    fi

    for filename in ${CONFIG_FILES}; do
        if [[ -f ${APP_ROOT}/${filename} ]]; then
            EchoCmd mkdir -p ${WAS_TEMP}/$(dirname ${filename}) || return 1
            EchoCmd cp ${APP_ROOT}/${filename} ${WAS_TEMP}/${filename} || return 1
        fi
    done
    
    return 0
}

#####################################################################
#
# Restore CONFIG_FILES (if any) from WAS_TEMP to APP_ROOT
#
Restore_IDSWebApp_Configuration()
{
    if [[ ${DEBUG} = TRUE ]]; then
        set -x
    fi
    
    for filename in ${CONFIG_FILES}; do
        if [[ -f ${WAS_TEMP}/${filename} ]]; then
            EchoCmd cp ${WAS_TEMP}/${filename} ${APP_ROOT}/${filename} || return 1
        fi
    done
    
    return 0
}


#####################################################################
#
Start_WAS()
{
    if [[ ${DEBUG} = TRUE ]]; then
        set -x
    fi
    
    EchoCmd "${WAS_HOME}/bin/startServer.sh" ${WAS_SERVER} || return $?
}

#####################################################################
#
Stop_WAS()
{
    if [[ ${DEBUG} = TRUE ]]; then
        set -x
    fi

    EchoCmd "${WAS_HOME}/bin/stopServer.sh" ${WAS_SERVER} || return $?
}

#####################################################################
#
Restart_WAS()
{
    if [[ ${DEBUG} = TRUE ]]; then
        set -x
    fi

    Stop_WAS
    Start_WAS || return $?
}

#####################################################################
#
# Un-deploy existing IDSWebApp.war (if found)...
#
Uninstall_IDSWebApp()
{
    if [[ ${DEBUG} = TRUE ]]; then
        set -x
    fi

    if [[ -d ${APP_ROOT} ]]; then
        EchoCmd ${WAS_HOME}/bin/wsadmin.sh '-c "\$AdminApp uninstall IDSWebApp.war"' || return $?
    fi
    return 0
}

#####################################################################
#
# Deploy new IDSWebApp.war...
#
Install_IDSWebApp()
{
    if [[ ${DEBUG} = TRUE ]]; then
        set -x
    fi

    EchoCmd ${WAS_HOME}/bin/wsadmin.sh '-conntype NONE -c "\$AdminApp install {'${IDSWebApp}'} {-configroot \"$CONFIG_ROOT\" -node \"$WAS_NODE\" -usedefaultbindings -nodeployejb -appname IDSWebApp.war -contextroot \"IDSWebApp\"}"'
    return $?
}

#####################################################################
#
# Display app-version and build-date of IDSWebAppInfo.xml file
#   or localized 'not found' message
#
ShowIDSWebAppInfo()
{
    if [[ ${DEBUG} = TRUE ]]; then
        set -x
    fi

    if [[ -f $1 ]]; then
        egrep '(app-version|build-date)' $1
    else
        ls $1 >/dev/null
    fi
}

#####################################################################
#
# "-v"
#
ShowVersionInfo()
{
    if [[ ${DEBUG} = TRUE ]]; then
        set -x
    fi
    
    # Show script version
    print "\n${PATCH_SCRIPT}:"
    print "    SCRIPT_VER:  ${SCRIPT_VER}"
    print "    SCRIPT_DATE: ${SCRIPT_DATE}"
    
    # Show version of new IDSWebApp
    print "\n${IDSWebApp}:"
    if [[ -f ${IDSWebApp} ]]; then
        save_PWD=$(pwd)
        cd ${WAS_TEMP}
        ${JAVA_HOME}/bin/jar -xf ${IDSWebApp} ${IDSWebAppInfo}
        cd ${save_PWD}
        ShowIDSWebAppInfo ${WAS_TEMP}/${IDSWebAppInfo}

    else
        ls ${IDSWebApp} >/dev/null
    fi
}

#####################################################################
#
# main
#

    InitGlobalVariables $* || return $?
    CreateTempDirectory || return $?
    
    if [[ ${OPTION_V} = TRUE ]]; then
        ShowVersionInfo
    else
        AssertFileExists ${IDSWebApp} || return $?
        Backup_IDSWebApp_Configuration || return $?
        if [[ ! -f ${WAS_HOME}/logs/${WAS_SERVER}/${WAS_SERVER}.pid ]]; then
            Start_WAS || return $?
        fi
        Uninstall_IDSWebApp || return $?
        Install_IDSWebApp || return $?
        Restore_IDSWebApp_Configuration || return $?
        Restart_WAS || return $?
    fi
    
    DeleteTempDirectory
    print "\n${APP_ROOT}:"
    ShowIDSWebAppInfo ${APP_ROOT}/${IDSWebAppInfo}

